==> webpdf-wsclient-1.0.1-sources.jar: net/webpdf/wsclient/schema/operation/SplitType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SplitType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SplitType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType"&gt;
 *       &lt;attribute name="mode" type="{http://schema.webpdf.de/1.0/operation}SplitModeType" default="last" /&gt;
 *       &lt;attribute name="pages" type="{http://www.w3.org/2001/XMLSchema}string" default="1" /&gt;
 *       &lt;attribute name="startPage" default="1"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="fileNameTemplate" type="{http://www.w3.org/2001/XMLSchema}string" default="page[%d]" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SplitType")
public class SplitType
    extends BaseToolboxType
{

    @XmlAttribute(name = "mode")
    protected SplitModeType mode;
    @XmlAttribute(name = "pages")
    protected String pages;
    @XmlAttribute(name = "startPage")
    protected Integer startPage;
    @XmlAttribute(name = "fileNameTemplate")
    protected String fileNameTemplate;

    /**
     * Gets the value of the mode property.
     * 
     * @return
     *     possible object is
     *     {@link SplitModeType }
     *     
     */
    public SplitModeType getMode() {
        if (mode == null) {
            return SplitModeType.LAST;
        } else {
            return mode;
        }
    }

    /**
     * Sets the value of the mode property.
     * 
     * @param value
     *     allowed object is
     *     {@link SplitModeType }
     *     
     */
    public void setMode(SplitModeType value) {
        this.mode = value;
    }

    public boolean isSetMode() {
        return (this.mode!= null);
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPages() {
        if (pages == null) {
            return "1";
        } else {
            return pages;
        }
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPages(String value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    /**
     * Gets the value of the startPage property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getStartPage() {
        if (startPage == null) {
            return  1;
        } else {
            return startPage;
        }
    }

    /**
     * Sets the value of the startPage property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setStartPage(int value) {
        this.startPage = value;
    }

    public boolean isSetStartPage() {
        return (this.startPage!= null);
    }

    public void unsetStartPage() {
        this.startPage = null;
    }

    /**
     * Gets the value of the fileNameTemplate property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFileNameTemplate() {
        if (fileNameTemplate == null) {
            return "page[%d]";
        } else {
            return fileNameTemplate;
        }
    }

    /**
     * Sets the value of the fileNameTemplate property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFileNameTemplate(String value) {
        this.fileNameTemplate = value;
    }

    public boolean isSetFileNameTemplate() {
        return (this.fileNameTemplate!= null);
    }

}

==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/operation/SplitType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import net.webpdf.wsclient.ParameterInterface;


/**
 * <p>Java class for SplitType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SplitType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType"&gt;
 *       &lt;attribute name="mode" type="{http://schema.webpdf.de/1.0/operation}SplitModeType" default="last" /&gt;
 *       &lt;attribute name="pages" type="{http://www.w3.org/2001/XMLSchema}string" default="1" /&gt;
 *       &lt;attribute name="startPage" default="1"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="fileNameTemplate" type="{http://www.w3.org/2001/XMLSchema}string" default="page[%d]" /&gt;
 *       &lt;attribute name="singleFileAsZip" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SplitType")
public class SplitType
    extends BaseToolboxType
    implements ParameterInterface
{

    @XmlAttribute(name = "mode")
    protected SplitModeType mode;
    @XmlAttribute(name = "pages")
    protected String pages;
    @XmlAttribute(name = "startPage")
    protected Integer startPage;
    @XmlAttribute(name = "fileNameTemplate")
    protected String fileNameTemplate;
    @XmlAttribute(name = "singleFileAsZip")
    protected Boolean singleFileAsZip;

    /**
     * Gets the value of the mode property.
     * 
     * @return
     *     possible object is
     *     {@link SplitModeType }
     *     
     */
    public SplitModeType getMode() {
        if (mode == null) {
            return SplitModeType.LAST;
        } else {
            return mode;
        }
    }

    /**
     * Sets the value of the mode property.
     * 
     * @param value
     *     allowed object is
     *     {@link SplitModeType }
     *     
     */
    public void setMode(SplitModeType value) {
        this.mode = value;
    }

    public boolean isSetMode() {
        return (this.mode!= null);
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPages() {
        if (pages == null) {
            return "1";
        } else {
            return pages;
        }
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPages(String value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    /**
     * Gets the value of the startPage property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getStartPage() {
        if (startPage == null) {
            return  1;
        } else {
            return startPage;
        }
    }

    /**
     * Sets the value of the startPage property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setStartPage(int value) {
        this.startPage = value;
    }

    public boolean isSetStartPage() {
        return (this.startPage!= null);
    }

    public void unsetStartPage() {
        this.startPage = null;
    }

    /**
     * Gets the value of the fileNameTemplate property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFileNameTemplate() {
        if (fileNameTemplate == null) {
            return "page[%d]";
        } else {
            return fileNameTemplate;
        }
    }

    /**
     * Sets the value of the fileNameTemplate property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFileNameTemplate(String value) {
        this.fileNameTemplate = value;
    }

    public boolean isSetFileNameTemplate() {
        return (this.fileNameTemplate!= null);
    }

    /**
     * Gets the value of the singleFileAsZip property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isSingleFileAsZip() {
        if (singleFileAsZip == null) {
            return true;
        } else {
            return singleFileAsZip;
        }
    }

    /**
     * Sets the value of the singleFileAsZip property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setSingleFileAsZip(boolean value) {
        this.singleFileAsZip = value;
    }

    public boolean isSetSingleFileAsZip() {
        return (this.singleFileAsZip!= null);
    }

    public void unsetSingleFileAsZip() {
        this.singleFileAsZip = null;
    }

}
